==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPivotDimensionDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDetailDescription } from "./WebPivotDimensionDetailDescription";
/**
 * @hidden
 */
var WebPivotDimensionDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionDetailDescriptionMetadata, _super);
    function WebPivotDimensionDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionDetailDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionDetailDescriptionMetadata.a == null) {
            WebPivotDimensionDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionDetailDescriptionMetadata.c(WebPivotDimensionDetailDescriptionMetadata.a);
        }
        if (a.k(WebPivotDimensionDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPivotDimensionDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebPivotDimensionDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("ChildLevel", "ExportedType:WebPivotDimension");
        a.item("MemberName", "String");
        a.item("Enabled", "Boolean");
        a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
        a.item("SortDirection", "ExportedType:string:SortingDirection");
        a.item("SortDirection@names", "None;Asc;Desc");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@stringUnion", "WebComponents;React");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("Width", "String");
        a.item("Level", "Number:double");
        a.item("MemberFunctionRef", "EventRef::memberFunction");
    };
    WebPivotDimensionDetailDescriptionMetadata.d = function (a) {
        WebPivotDimensionDetailDescriptionMetadata.b(a);
        a.ad("WebPivotDimensionDetail", function () { return new WebPivotDimensionDetailDescription(); });
        a.ac("WebPivotDimensionDetail", WebPivotDimensionDetailDescriptionMetadata.a);
    };
    WebPivotDimensionDetailDescriptionMetadata.$t = markType(WebPivotDimensionDetailDescriptionMetadata, 'WebPivotDimensionDetailDescriptionMetadata');
    WebPivotDimensionDetailDescriptionMetadata.a = null;
    return WebPivotDimensionDetailDescriptionMetadata;
}(Base));
export { WebPivotDimensionDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebPivotDimensionDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebPivotDimensionDetailDescription } from "./WebPivotDimensionDetailDescription";
/**
 * @hidden
 */
var WebPivotDimensionDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionDetailDescriptionMetadata, _super);
    function WebPivotDimensionDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionDetailDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionDetailDescriptionMetadata.a == null) {
            WebPivotDimensionDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionDetailDescriptionMetadata.c(WebPivotDimensionDetailDescriptionMetadata.a);
        }
        if (a.k(WebPivotDimensionDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPivotDimensionDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebPivotDimensionDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("ChildLevel", "ExportedType:WebPivotDimension");
        a.item("MemberName", "String");
        a.item("DisplayName", "String");
        a.item("Enabled", "Boolean");
        a.item("Filter", "ExportedType:WebFilteringExpressionsTree");
        a.item("Sortable", "Boolean");
        a.item("SortDirection", "ExportedType:string:SortingDirection");
        a.item("SortDirection@names", "None;Asc;Desc");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@stringUnion", "WebComponents;React");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("Width", "String");
        a.item("Level", "Number:double");
        a.item("HorizontalSummary", "Boolean");
        a.item("MemberFunctionRef", "EventRef::memberFunction");
    };
    WebPivotDimensionDetailDescriptionMetadata.d = function (a) {
        WebPivotDimensionDetailDescriptionMetadata.b(a);
        a.ae("WebPivotDimensionDetail", function () { return new WebPivotDimensionDetailDescription(); });
        a.ad("WebPivotDimensionDetail", WebPivotDimensionDetailDescriptionMetadata.a);
    };
    WebPivotDimensionDetailDescriptionMetadata.$t = markType(WebPivotDimensionDetailDescriptionMetadata, 'WebPivotDimensionDetailDescriptionMetadata');
    WebPivotDimensionDetailDescriptionMetadata.a = null;
    return WebPivotDimensionDetailDescriptionMetadata;
}(Base));
export { WebPivotDimensionDetailDescriptionMetadata };
